@@ -1,14 +1,14 @@
 package Net::Google::Code::TypicalRoles;
-use Moose::Role;
+use Any::Moose 'Role';
 
 with 'Net::Google::Code::Role::Fetchable';
 with 'Net::Google::Code::Role::URL';
 with 'Net::Google::Code::Role::HTMLTree';
 with 'Net::Google::Code::Role::Authentication';
-with 'Net::Google::Code::Role::DateTime';
 with 'Net::Google::Code::Role::Pageable';
+with 'Net::Google::Code::Role::Predefined';
 
-no Moose::Role;
+no Any::Moose;
 
 1;
 
